#include <boost/math/special_functions/sinc.hpp>
#include <boost/math/special_functions/sinhc.hpp>
#include "../boostmath/macros.hpp"

UNARY_BOOST_FUNCTION(sinc_pi, double);
UNARY_BOOST_FUNCTION(sinhc_pi, double);
